import math
import numpy as np
from matplotlib.path import Path

s2 = math.sqrt(2) / 2
# Define the marker shape
verts = np.array(
    [[-1, 0], [1, 0], [0, 1], [0, -1], [s2, s2], [-s2, -s2], [-s2, s2], [s2, -s2]]
)
codes = [
    Path.MOVETO,
    Path.LINETO,
    Path.MOVETO,
    Path.LINETO,
    Path.MOVETO,
    Path.LINETO,
    Path.MOVETO,
    Path.LINETO,
]
star = Path(verts, codes)



from setuptools import setup, find_packages

setup(
    name="betterstar",
    version="1.0.1",
    author="Ole Meiforth",
    description="A better looking star marker for matplotlib plots.",
    long_description=open("README.md", "r").read(),
    long_description_content_type="text/markdown",
    url='https://github.com/muederotter/betterstar',
    packages=find_packages(),
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    python_requires=">=3.6",
    install_requires=["numpy", "matplotlib"],
)
